@@ -23,9 +23,7 @@ class BaseRepository:
     Base repository class for doing all the database operations using Beanie for NoSQL database.
     """
 
-    def __init__(self, document: Optional[Type[DocumentType]] = None, db: Optional[AsyncIOMotorDatabase] = None):
-        if not document and not db:
-            raise BadRequestError("Either document or db must be provided")
+    def __init__(self, document: Type[DocumentType] = None, db: AsyncIOMotorDatabase = None):
         self.document = document
         self.db = db
 
@@ -74,6 +72,7 @@ class BaseRepository:
     def get_base_document_fields(self) -> Dict[str, Any]:
         """Get the base document fields"""
         return {
+            "id": PydanticObjectId(), 
             "uuid": str(uuid4()),  
             "created_at": datetime.now(UTC),
             "updated_at": datetime.now(UTC)
@@ -88,7 +87,7 @@ class BaseRepository:
                 error_type="PyMongoError",
                 message=f"Failed to {operation}"
             )
-        raise BadRequestError(detail=str(error))
+        raise error
 
     async def create(self, obj: T, collection_name: Optional[str] = None) -> Dict[str, Any]:
         """Create a new document in the collection"""
@@ -98,11 +97,11 @@ class BaseRepository:
             if collection_name:
                 collection = self.get_collection(collection_name)
                 result = await collection.insert_one({**self.get_base_document_fields(), **obj_dict})
-                return await self.get_by_attr("_id", result.inserted_id, collection_name)
+                return await self.get_by_attr("id", result.inserted_id, collection_name)
             
             model_instance = self.document(**obj_dict)
             await model_instance.insert()
-            return await self.get_by_attr("_id", model_instance.id)
+            return await self.get_by_attr("id", model_instance.id)
             
         except Exception as e:
             await self._handle_mongo_error("create document", e)
@@ -116,7 +115,7 @@ class BaseRepository:
                 collection = self.get_collection(collection_name)
                 documents = [{**self.get_base_document_fields(), **get_obj(item)} for item in data]
                 result = await collection.insert_many(documents)
-                return [{"_id": id, **doc} for id, doc in zip(result.inserted_ids, documents)]
+                return [{"id": id, **doc} for id, doc in zip(result.inserted_ids, documents)]
             
             model_instances = [self.document(**get_obj(item)) for item in data]
             await self.document.insert_many(model_instances)
@@ -141,25 +140,27 @@ class BaseRepository:
                 if result.matched_count == 0:
                     raise NotFoundError(detail=f"Document with id {id} not found")
                 
-                return await self.get_by_attr("_id", object_id, collection_name)
+                return await self.get_by_attr("id", object_id, collection_name)
             
             result = await self.document.get(object_id)
             if not result:
                 raise NotFoundError(detail=f"Document with id {id} not found")
                 
             await result.update(Set(obj_dict))
-            return await self.get_by_attr("_id", object_id)
+            return await self.get_by_attr("id", object_id)
             
         except Exception as e:
             await self._handle_mongo_error("update document", e)
 
     async def get_by_attr(self, attr: str, value: Any, collection_name: Optional[str] = None) -> Dict[str, Any]:
         """Get a document by a specific attribute"""
+        if attr == "id":
+            value = ObjectId(value)
         try:
             if collection_name:
                 collection = self.get_collection(collection_name)
-                if attr == "_id":
-                    value = ObjectId(value)
+                if attr == "id":
+                    attr = "_id"
                 result = await collection.find_one({attr: value})
                 if not result:
                     raise NotFoundError(detail=f"Document with {attr}={value} not found")
@@ -167,7 +168,7 @@ class BaseRepository:
             
             if not hasattr(self.document, attr):
                 raise BadRequestError(f"Attribute {attr} not found in document {self.document.__name__}")
-                
+
             result = await self.document.find_one(getattr(self.document, attr) == value)
             return self._convert_to_json_serializable(result)
             
@@ -331,7 +332,7 @@ class BaseRepository:
             if schema.ordering:
                 pipeline.append({
                     "$sort": {
-                        "_id": ASCENDING if schema.ordering == "asc" else DESCENDING
+                        "_id": 1 if schema.ordering == "asc" else -1
                     }
                 })
             
@@ -359,100 +360,4 @@ class BaseRepository:
             }
             
         except Exception as e:
-            await self._handle_mongo_error("get unique values", e)
-
-    async def add_field(self, column: AddColumnField, collection_name: Optional[str] = None) -> bool:
-        """Add a new field to all documents in the collection"""
-        try:
-            collection = self.get_collection(collection_name) if collection_name else self.document.get_motor_collection()
-            
-            await collection.update_many(
-                {column.column_field: {"$exists": False}},
-                {"$set": {column.column_field: column.column_default or self.get_default_for_type(column.column_type)}},
-                hint="_id_"
-            )
-
-            if column.is_unique and column.column_type != FieldTypeEnum.DATETIME:
-                await collection.create_index(column.column_field, unique=True)
-            
-            return True
-            
-        except Exception as e:
-            await self._handle_mongo_error("add field", e)
-
-    async def delete_field(self, column_name: str, collection_name: Optional[str] = None) -> bool:
-        """Delete a field from all documents in the collection"""
-        try:
-            collection = self.get_collection(collection_name) if collection_name else self.document.get_motor_collection()
-            
-            result = await collection.update_many(
-                {},
-                {"$unset": {column_name: ""}}
-            )
-            
-            if result.modified_count == 0:
-                raise NotFoundError(detail=f"Field {column_name} not found")
-                
-            return True
-            
-        except Exception as e:
-            await self._handle_mongo_error("delete field", e)
-
-    async def create_collection(self, collection_data: CreateCollectionSchema) -> bool:
-        """Create a new collection with default values"""
-        try:
-            collection = self.db[collection_data.collection_name]
-            dafault_fields = collection_data.default_values or {}
-            full_doc = {**self.get_base_document_fields(), **dafault_fields}
-            await collection.insert_one(full_doc)
-            return True
-            
-        except Exception as e:
-            await self._handle_mongo_error("create collection", e)
-
-    async def delete_collection(self, collection_name: str) -> bool:
-        """Delete a collection"""
-        try:
-            await self.db.drop_collection(collection_name)
-            return True
-            
-        except Exception as e:
-            await self._handle_mongo_error("delete collection", e)
-
-    async def rename_collection(self, old_name: str, new_name: str) -> bool:
-        """Rename a collection in MongoDB"""
-        try:
-            # Get full collection names
-            full_old = f"{self.db.name}.{old_name}"
-            full_new = f"{self.db.name}.{new_name}"
-
-            admin_db = self.db.client.admin
-
-            await admin_db.command({
-                "renameCollection": full_old,
-                "to": full_new,
-                "dropTarget": False 
-            })
-
-            return True
-        except Exception as e:
-            await self._handle_mongo_error("rename collection", e)
-
-    async def get_collection_names(self) -> List[str]:
-        """Get all collection names"""
-        return await self.db.list_collection_names()
-
-    @staticmethod
-    def get_default_for_type(field_type: FieldTypeEnum) -> Any:
-        """Get default value for a field type"""
-        default_values = {
-            FieldTypeEnum.STR: "",
-            FieldTypeEnum.INT: 0,
-            FieldTypeEnum.BOOL: False,
-            FieldTypeEnum.FLOAT: 0.0,
-            FieldTypeEnum.LIST: [],
-            FieldTypeEnum.DICT: {},
-            FieldTypeEnum.DATETIME: datetime.now()
-        }
-        return default_values.get(field_type) or ""
-
+            await self._handle_mongo_error("get unique values", e)
\ No newline at end of file
