@@ -5,8 +5,8 @@ class BaseCollectionService:
     def __init__(self, repository: BaseCollectionRepository):
         self.repository = repository
 
-    async def create_collection(self, collection_name: str, schema: CreateCollectionSchema):
-        return await self.repository.create_collection(collection_name, schema)
+    async def create_collection(self, collection: CreateCollectionSchema):
+        return await self.repository.create_collection(collection)
     
     async def delete_collection(self, collection_name: str):
         return await self.repository.delete_collection(collection_name)
